@@ -10,8 +10,6 @@ class ExampleMenuProvider(GObject.GObject, Nautilus.MenuProvider):
         top_menuitem = Nautilus.MenuItem(
             name="ExampleMenuProvider::Foo",
             label="Foo",
-            tip="",
-            icon="",
         )
 
         submenu = Nautilus.Menu()
@@ -20,8 +18,6 @@ class ExampleMenuProvider(GObject.GObject, Nautilus.MenuProvider):
         sub_menuitem = Nautilus.MenuItem(
             name="ExampleMenuProvider::Bar",
             label="Bar",
-            tip="",
-            icon="",
         )
         submenu.append_item(sub_menuitem)
 
@@ -38,16 +34,12 @@ class ExampleMenuProvider(GObject.GObject, Nautilus.MenuProvider):
             Nautilus.MenuItem(
                 name="ExampleMenuProvider::Bar2",
                 label="Bar2",
-                tip="",
-                icon="",
             )
         )
 
         menuitem = Nautilus.MenuItem(
             name="ExampleMenuProvider::Foo2",
             label="Foo2",
-            tip="",
-            icon="",
         )
         menuitem.set_submenu(submenu)
 
